@@ -1,10 +1,17 @@
-utils::globalVariables(c("corresponding_institution_ids", "corresponding_author_name", "corresponding_author_affiliation", "corresponding_author_country", "C1_ID"))
+utils::globalVariables(c(
+  "corresponding_institution_ids",
+  "corresponding_author_name",
+  "corresponding_author_affiliation",
+  "corresponding_author_country",
+  "C1_ID"
+))
 
 
 importOAFiles <- function(file) {
   objName <- load(file)
   if (!isTRUE(inherits(eval(parse(text = objName)), c("list")))) {
-    message("the rdata file does not contain a valid object!\nopenalexR API requests have to be exported as 'list'.\nPlease set argument output='list' when use oafetch.\n
+    message(
+      "the rdata file does not contain a valid object!\nopenalexR API requests have to be exported as 'list'.\nPlease set argument output='list' when use oafetch.\n
 
     ## Example ##
   works_from_dois <- oa_fetch(\n
@@ -13,7 +20,8 @@ importOAFiles <- function(file) {
   output = 'list',
   verbose = TRUE\n
   )
-    ")
+    "
+    )
     return(NA)
   }
   if (length(objName) != 1) {
@@ -34,14 +42,13 @@ apiOA2df <- function(file) {
     type <- "data.frame"
   }
 
-  switch(type,
+  switch(
+    type,
     "list" = {
       df <- purrr::map_dfr(DATA, extract_all_metadata)
       df <- relabelling_OA_API(df)
     },
-    "data.frame" = {
-
-    }
+    "data.frame" = {}
   )
 
   df$AF <- df$AU
@@ -57,7 +64,8 @@ apiOA2df <- function(file) {
   DE <- df$DE
   if ("DI" %in% names(df)) {
     df <- df %>%
-      mutate(across(all_of(label), toupper),
+      mutate(
+        across(all_of(label), toupper),
         DI = gsub("https://doi.org/", "", DI),
         DI = ifelse(DI == "null", NA, DI)
       )
@@ -72,9 +80,15 @@ apiOA2df <- function(file) {
 
   ## transform Country code in names
   CO <- strsplit(df$AU_CO, ";")
-  CO <- data.frame(Alpha2 = trimws(unlist(CO)), id_oa = rep(df$id_oa, lengths(CO)))
+  CO <- data.frame(
+    Alpha2 = trimws(unlist(CO)),
+    id_oa = rep(df$id_oa, lengths(CO))
+  )
   CO <- CO %>%
-    left_join(openalexR::countrycode %>% select("Alpha2", "Country"), by = "Alpha2") %>%
+    left_join(
+      openalexR::countrycode %>% select("Alpha2", "Country"),
+      by = "Alpha2"
+    ) %>%
     mutate(Country = toupper(Country)) %>%
     group_by(id_oa) %>%
     summarize(
@@ -83,12 +97,18 @@ apiOA2df <- function(file) {
   df <- df %>%
     select(-"AU_CO") %>%
     left_join(CO, by = "id_oa")
-  
+
   ## transform Corresponding Country code in names
   CO <- strsplit(df$AU1_CO, ";")
-  CO <- data.frame(Alpha2 = trimws(unlist(CO)), id_oa = rep(df$id_oa, lengths(CO)))
+  CO <- data.frame(
+    Alpha2 = trimws(unlist(CO)),
+    id_oa = rep(df$id_oa, lengths(CO))
+  )
   CO <- CO %>%
-    left_join(openalexR::countrycode %>% select("Alpha2", "Country"), by = "Alpha2") %>%
+    left_join(
+      openalexR::countrycode %>% select("Alpha2", "Country"),
+      by = "Alpha2"
+    ) %>%
     mutate(Country = toupper(Country)) %>%
     group_by(id_oa) %>%
     summarize(
@@ -160,49 +180,80 @@ extract_basic_info <- function(article) {
 extract_authors <- function(article) {
   authors <- article$authorships
   if (length(authors) > 0) {
-    map_df(authors, ~ tibble(
-      # Remove the prefix from the author ID
-      author_id = if (!is.null(.x$author$id)) gsub("https://openalex.org/", "", .x$author$id) else NA,
-
-      # Author's name
-      name = if (!is.null(.x$author$display_name)) .x$author$display_name else NA,
-
-      # ORCID (if available)
-      orcid = if (!is.null(.x$author$orcid)) .x$author$orcid else NA,
-
-      # Author's position
-      position = if (!is.null(.x$author_position)) .x$author_position else NA,
-
-      # Affiliations: Names of institutions
-      institutions = if (!is.null(.x$institutions) && length(.x$institutions) > 0) {
-        paste(map_chr(.x$institutions, "display_name", .default = NA), collapse = "; ")
-      } else {
-        NA
-      },
-
-      # Affiliations: Institution IDs (removing prefix)
-      institution_ids = if (!is.null(.x$institutions) && length(.x$institutions) > 0) {
-        paste(map_chr(.x$institutions, ~ gsub("https://openalex.org/", "", .x$id), .default = NA), collapse = "; ")
-      } else {
-        NA
-      },
-
-      # Countries of affiliations
-      countries = if (!is.null(.x$countries) && length(.x$countries) > 0) {
-        paste(.x$countries, collapse = "; ")
-      } else {
-        NA
-      }
-    ))
+    map_df(
+      authors,
+      ~ tibble(
+        # Remove the prefix from the author ID
+        author_id = if (!is.null(.x$author$id)) {
+          gsub("https://openalex.org/", "", .x$author$id)
+        } else {
+          NA_character_
+        },
+        # Author's name
+        name = if (!is.null(.x$author$display_name)) {
+          .x$author$display_name
+        } else {
+          NA_character_
+        },
+        # ORCID (if available)
+        orcid = if (!is.null(.x$author$orcid)) {
+          .x$author$orcid
+        } else {
+          NA_character_
+        },
+        # Author's position
+        position = if (!is.null(.x$author_position)) {
+          .x$author_position
+        } else {
+          NA_character_
+        },
+        # Affiliations: Names of institutions
+        institutions = if (
+          !is.null(.x$institutions) && length(.x$institutions) > 0
+        ) {
+          inst_names <- map_chr(.x$institutions, function(inst) {
+            if (!is.null(inst$display_name)) {
+              inst$display_name
+            } else {
+              NA_character_
+            }
+          })
+          paste(inst_names, collapse = "; ")
+        } else {
+          NA_character_
+        },
+        # Affiliations: Institution IDs (removing prefix)
+        institution_ids = if (
+          !is.null(.x$institutions) && length(.x$institutions) > 0
+        ) {
+          inst_ids <- map_chr(.x$institutions, function(inst) {
+            if (!is.null(inst$id)) {
+              gsub("https://openalex.org/", "", inst$id)
+            } else {
+              NA_character_
+            }
+          })
+          paste(inst_ids, collapse = "; ")
+        } else {
+          NA_character_
+        },
+        # Countries of affiliations
+        countries = if (!is.null(.x$countries) && length(.x$countries) > 0) {
+          paste(.x$countries, collapse = "; ")
+        } else {
+          NA_character_
+        }
+      )
+    )
   } else {
     tibble(
-      author_id = NA,
-      name = NA,
-      orcid = NA,
-      position = NA,
-      institutions = NA,
-      institution_ids = NA,
-      countries = NA
+      author_id = NA_character_,
+      name = NA_character_,
+      orcid = NA_character_,
+      position = NA_character_,
+      institutions = NA_character_,
+      institution_ids = NA_character_,
+      countries = NA_character_
     )
   }
 }
@@ -221,13 +272,41 @@ compress_author_affiliation_info <- function(authors_info) {
 
   # Check for the existence of columns before concatenating
   compressed_info <- tibble(
-    author_id = if ("author_id" %in% names(authors_info)) concat_non_na(authors_info$author_id) else NA,
-    name = if ("name" %in% names(authors_info)) concat_non_na(authors_info$name) else NA,
-    orcid = if ("orcid" %in% names(authors_info)) concat_non_na(authors_info$orcid) else NA,
-    position = if ("position" %in% names(authors_info)) concat_non_na(authors_info$position) else NA,
-    institutions = if ("institutions" %in% names(authors_info)) concat_non_na(authors_info$institutions) else NA,
-    institution_ids = if ("institution_ids" %in% names(authors_info)) concat_non_na(authors_info$institution_ids) else NA,
-    countries = if ("countries" %in% names(authors_info)) concat_non_na(authors_info$countries) else NA
+    author_id = if ("author_id" %in% names(authors_info)) {
+      concat_non_na(authors_info$author_id)
+    } else {
+      NA
+    },
+    name = if ("name" %in% names(authors_info)) {
+      concat_non_na(authors_info$name)
+    } else {
+      NA
+    },
+    orcid = if ("orcid" %in% names(authors_info)) {
+      concat_non_na(authors_info$orcid)
+    } else {
+      NA
+    },
+    position = if ("position" %in% names(authors_info)) {
+      concat_non_na(authors_info$position)
+    } else {
+      NA
+    },
+    institutions = if ("institutions" %in% names(authors_info)) {
+      concat_non_na(authors_info$institutions)
+    } else {
+      NA
+    },
+    institution_ids = if ("institution_ids" %in% names(authors_info)) {
+      concat_non_na(authors_info$institution_ids)
+    } else {
+      NA
+    },
+    countries = if ("countries" %in% names(authors_info)) {
+      concat_non_na(authors_info$countries)
+    } else {
+      NA
+    }
   )
 
   return(compressed_info)
@@ -282,7 +361,9 @@ abstract_build <- function(ab) {
 
 # Extract referenced citations
 extract_cited_references <- function(article) {
-  if (!is.null(article$referenced_works) && length(article$referenced_works) > 0) {
+  if (
+    !is.null(article$referenced_works) && length(article$referenced_works) > 0
+  ) {
     cited_references <- article$referenced_works %>%
       map_chr(~ gsub("https://openalex.org/", "", .x)) %>%
       paste(collapse = "; ")
@@ -297,11 +378,13 @@ extract_cited_references <- function(article) {
 extract_grants <- function(article) {
   if (!is.null(article$grants) && length(article$grants) > 0) {
     grants_info <- article$grants %>%
-      map_chr(~ paste(
-        ifelse(!is.null(.x$award_id), .x$award_id, NA),
-        ifelse(!is.null(.x$funding_agency), .x$funding_agency, NA),
-        sep = ": "
-      )) %>%
+      map_chr(
+        ~ paste(
+          ifelse(!is.null(.x$award_id), .x$award_id, NA),
+          ifelse(!is.null(.x$funding_agency), .x$funding_agency, NA),
+          sep = ": "
+        )
+      ) %>%
       paste(collapse = "; ")
   } else {
     grants_info <- NA
@@ -312,7 +395,10 @@ extract_grants <- function(article) {
 
 # Extract SDGs
 extract_sdg <- function(article) {
-  if (!is.null(article$sustainable_development_goals) && length(article$sustainable_development_goals) > 0) {
+  if (
+    !is.null(article$sustainable_development_goals) &&
+      length(article$sustainable_development_goals) > 0
+  ) {
     tibble(
       sdg_display_name = article$sustainable_development_goals %>%
         map_chr(~ ifelse(!is.null(.x$display_name), .x$display_name, NA)) %>%
@@ -337,7 +423,9 @@ extract_sdg <- function(article) {
 extract_mesh_terms <- function(article) {
   if (!is.null(article$mesh) && length(article$mesh) > 0) {
     mesh_terms <- article$mesh %>%
-      map_chr(~ ifelse(!is.null(.x$descriptor_name), .x$descriptor_name, NA)) %>%
+      map_chr(
+        ~ ifelse(!is.null(.x$descriptor_name), .x$descriptor_name, NA)
+      ) %>%
       paste(collapse = "; ")
   } else {
     mesh_terms <- NA
@@ -363,12 +451,14 @@ extract_keywords <- function(article) {
 extract_concepts <- function(article) {
   if (!is.null(article$concepts) && length(article$concepts) > 0) {
     concepts_info <- article$concepts %>%
-      map_chr(~ paste(
-        ifelse(!is.null(.x$display_name), .x$display_name, NA),
-        "(",
-        ifelse(!is.null(.x$score), .x$score, NA),
-        ")"
-      )) %>%
+      map_chr(
+        ~ paste(
+          ifelse(!is.null(.x$display_name), .x$display_name, NA),
+          "(",
+          ifelse(!is.null(.x$score), .x$score, NA),
+          ")"
+        )
+      ) %>%
       paste(collapse = "; ")
   } else {
     concepts_info <- NA
@@ -393,9 +483,12 @@ extract_topics <- function(article) {
 # Extract additional information (citations per year, FWCI, etc.)
 extract_additional_info <- function(article) {
   yearly_citations <- if (!is.null(article$counts_by_year)) {
-    paste(sapply(article$counts_by_year, function(count) {
-      paste(count$year, count$cited_by_count, sep = ": ")
-    }), collapse = "; ")
+    paste(
+      sapply(article$counts_by_year, function(count) {
+        paste(count$year, count$cited_by_count, sep = ": ")
+      }),
+      collapse = "; "
+    )
   } else {
     NA
   }
@@ -403,8 +496,16 @@ extract_additional_info <- function(article) {
   tibble(
     yearly_citations = yearly_citations,
     fwci = ifelse(!is.null(article$fwci), article$fwci, NA),
-    apc_value = ifelse(!is.null(article$apc_list$value), article$apc_list$value, NA),
-    apc_currency = ifelse(!is.null(article$apc_list$currency), article$apc_list$currency, NA),
+    apc_value = ifelse(
+      !is.null(article$apc_list$value),
+      article$apc_list$value,
+      NA
+    ),
+    apc_currency = ifelse(
+      !is.null(article$apc_list$currency),
+      article$apc_list$currency,
+      NA
+    ),
     has_fulltext = article$has_fulltext
   )
 }
@@ -421,40 +522,48 @@ extract_corresponding_info <- function(authorships) {
     ))
   }
   corr_idx <- which(sapply(authorships, function(a) isTRUE(a$is_corresponding)))
-  
+
   if (length(corr_idx) > 0) {
     # Se esiste almeno un corresponding author, prendi il primo
     selected_author <- authorships[[corr_idx[1]]]
   } else {
     # Altrimenti prendi il primo autore
-    first_idx <- which(sapply(authorships, function(a) a$author_position == "first"))
+    first_idx <- which(sapply(authorships, function(a) {
+      a$author_position == "first"
+    }))
     selected_author <- authorships[[first_idx[1]]]
   }
-  
+
   # Estrai nome e ID autore
   display_name <- selected_author$author$display_name
   id <- selected_author$author$id
-  
+
   # Estrai il paese se disponibile
-  if (!is.null(selected_author$countries) && length(selected_author$countries) > 0) {
+  if (
+    !is.null(selected_author$countries) && length(selected_author$countries) > 0
+  ) {
     country <- selected_author$countries[[1]]
-  } else if (!is.null(selected_author$institutions) &&
-             length(selected_author$institutions) > 0 &&
-             !is.null(selected_author$institutions[[1]]$country_code)) {
+  } else if (
+    !is.null(selected_author$institutions) &&
+      length(selected_author$institutions) > 0 &&
+      !is.null(selected_author$institutions[[1]]$country_code)
+  ) {
     country <- selected_author$institutions[[1]]$country_code
   } else {
     country <- NA
   }
-  
+
   # Estrai l'affiliazione se disponibile
-  if (!is.null(selected_author$affiliations) &&
+  if (
+    !is.null(selected_author$affiliations) &&
       length(selected_author$affiliations) > 0 &&
-      !is.null(selected_author$affiliations[[1]]$raw_affiliation_string)) {
+      !is.null(selected_author$affiliations[[1]]$raw_affiliation_string)
+  ) {
     affiliation <- selected_author$affiliations[[1]]$raw_affiliation_string
   } else {
     affiliation <- NA
   }
-  
+
   return(tibble(
     AU_CORR = display_name,
     AU_CORR_ID = id,
@@ -483,4 +592,3 @@ extract_all_metadata <- function(article) {
     extract_additional_info(article)
   )
 }
-
