@@ -28,7 +28,8 @@ csvScopus2df <- function(file) {
 
   # Authors' names cleaning (surname and initials)
   DATA$AU <- gsub("\\.", "", DATA$AU)
-  DATA$AU <- gsub(",", ";", DATA$AU)
+  #DATA$AU <- gsub(",", ";", DATA$AU)
+  DATA$AU <- gsub(",", "", DATA$AU)
 
   ### store raw affiliation format to extract link among authors and affiliations
   DATA$C1raw <- DATA$C1
@@ -72,8 +73,9 @@ labelling <- function(DATA) {
   df_tag <- data.frame(
     rbind(
       c("Abbreviated Source Title", "JI"),
-      c("Authors with affiliations", "C1"),
-      c("Author Addresses", "C1"),
+      c("Affiliations", "C1"),
+      c("Authors with affiliations", "C1_raw"),
+      c("Author Addresses", "C1_raw"),
       c("Authors", "AU"),
       c("Author Names", "AU"),
       c("Author full names", "AF"),
@@ -115,38 +117,14 @@ labelling <- function(DATA) {
     mutate(tag = ifelse(is.na(tag), orig, tag))
 
   names(DATA) <- label$tag
+  
+  if (!"C1" %in% names(DATA)) {
+    if ("C1_raw" %in% names(DATA)) {
+      DATA$C1 <- DATA$C1_raw
+    } else {
+      DATA$C1 <- NA
+    }
+  }
 
-
-  # label <- names(DATA)
-  # label <- gsub("Abbreviated Source Title","JI",label)
-  # label <- gsub("Authors with affiliations","C1",label)
-  # label <- gsub("Author Addresses","C1",label)
-  # #label <- gsub("Affiliations","RP",label)
-  # label <- gsub("Authors","AU",label)
-  # label <- gsub("Author Names","AU",label)
-  # label <- gsub("Source title","SO",label)
-  # label <- gsub("Titles","TI",label)
-  # label <- gsub("Title","TI",label)
-  # label <- gsub("Publication Year","PY",label)
-  # label <- gsub("Year","PY",label)
-  # label <- gsub("Volume","VL",label)
-  # label <- gsub("Issue","IS",label)
-  # label <- gsub("Page count","PP",label)
-  # label <- gsub("Cited by","TC",label)
-  # label <- gsub("DOI","DI",label)
-  # label <- gsub("Link","URL",label)
-  # label <- gsub("Abstract","AB",label)
-  # label <- gsub("Author Keywords","DE",label)
-  # label <- gsub("Index Keywords","ID",label)
-  # label <- gsub("Funding Details","FU",label)
-  # label <- gsub("Funding Text 1","FX",label)
-  # label <- gsub("References","CR",label)
-  # label <- gsub("Correspondence Address","RP",label)
-  # label <- gsub("Funding Details","FU",label)
-  # label <- gsub("Language of Original Document","LA",label)
-  # label <- gsub("Document Type","DT",label)
-  # label <- gsub("Source","DB",label)
-  # label <- gsub("EID","UT",label)
-  # names(DATA) <- label
   return(DATA)
 }
